NativeLibrary class

Constructors

NativeLibrary(DynamicLibrary dynamicLibrary)
The symbols are looked up in dynamicLibrary.
NativeLibrary.fromLookup(Pointer<T> lookup<T extends NativeType>(String symbolName))
The symbols are looked up with lookup.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tor_client_bootstrap(Pointer<Void> client) → bool
tor_client_set_dormant(Pointer<Void> client, bool soft_mode) → void
tor_get_nofile_limit() → int
tor_hello() → void
tor_last_error_message() → Pointer<Char>
tor_proxy_stop(Pointer<Void> proxy) → void
tor_set_nofile_limit(int limit) → int
tor_start(int socks_port, Pointer<Char> state_dir, Pointer<Char> cache_dir) → Tor
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited